@@ -1,5 +1,5 @@
 AnalyzeHRbyEpisodes <-
-function(HRVData, Tag="", func, verbose=NULL) {
+function(HRVData, Tag="", func, ..., verbose=NULL) {
 # ----------------------------------------------
 # Analyzes Heart Rate using Episodes information
 # ----------------------------------------------
@@ -9,6 +9,9 @@ function(HRVData, Tag="", func, verbose=NULL) {
 
 #  Function func musts receive a vector and returns an object
 
+  funcToApply =  match.fun(func)
+  nameFunc = deparse(substitute(func))
+
 	if (!is.null(verbose)) {
 		cat("  --- Warning: deprecated argument, using SetVerbose() instead ---\n    --- See help for more information!! ---\n")
 		SetVerbose(HRVData,verbose)
@@ -16,7 +19,7 @@ function(HRVData, Tag="", func, verbose=NULL) {
 	
 	if (HRVData$Verbose) {
 		cat("** Applying function to heart rate signal using episodic information **\n");
-      cat("   Function: ",func,"()\n",sep="")
+    cat("   Function: ",nameFunc,"()\n",sep="")
    }
 
    if (is.null(HRVData$Episodes)) {
@@ -37,10 +40,10 @@ function(HRVData, Tag="", func, verbose=NULL) {
 
    vectors=SplitHRbyEpisodes(HRVData,Tag=Tag)
 
-   cadIn=sprintf("%s(vectors$InEpisodes)",func)
-   cadOut=sprintf("%s(vectors$OutEpisodes)",func)
+   resultIn=funcToApply(vectors$InEpisodes,...)
+   resultOut=funcToApply(vectors$OutEpisodes,...)
    
-   result=list(resultIn=eval(parse(text=cadIn)),resultOut=eval(parse(text=cadOut)))
+   result=list(resultIn=resultIn,resultOut=resultOut)
 
    return(result)
 
