@@ -53,9 +53,16 @@ function(HRVData, long=50, last=13, minbpm=25, maxbpm=200, mini=NULL, maxi=NULL,
       	v = hr[max(index-long,1):index-1]
       	M = sum(v)/length(v)
 
-      	if((100*abs((hr[index]-hr[index-1])/hr[index-1]) < ulast | 100*abs((hr[index]-hr[index+1])/hr[index+1]) < ulast | 100*abs((hr[index]-M)/M) < umean) & hr[index]>=minbpm & hr[index]<=maxbpm) {
+		if((100*abs((hr[index]-hr[index-1])/hr[index-1]) < ulast | 100*abs((hr[index]-hr[index+1])/hr[index+1]) < ulast | 100*abs((hr[index]-M)/M) < umean) & hr[index]>=minbpm & hr[index]<=maxbpm) {
         	index=index+1
-         } 
+			tmp=10+sd(hr[max(index-long,1):index-1])
+			if(tmp<12)
+          		tmp=12;
+       		if(tmp>20)
+           		tmp=20;
+       		ulast=tmp;
+       		umean=1.5*tmp; 
+      	} 
 
       	else {
          	hr=hr[-index]
