@@ -12,6 +12,8 @@ function(HRVData, RecordName, RecordPath=".", verbose=NULL) {
 	}
 	
 	dir=getwd()
+  on.exit(setwd(dir))
+
 	if (HRVData$Verbose) {
 		cat("   Path:",RecordPath,"\n")
 	}
@@ -31,8 +33,8 @@ function(HRVData, RecordName, RecordPath=".", verbose=NULL) {
 			cat("      Time information in header:",timeinfo,"\n")
 		}
 	} else {
+		timeinfo="00:00:00"
 		if (HRVData$Verbose) {
-			timeinfo="00:00:00"
 			cat("      No time information in header:",timeinfo,"\n")
 		}
 	}
@@ -44,8 +46,8 @@ function(HRVData, RecordName, RecordPath=".", verbose=NULL) {
 			cat("      Date information in header:",dateinfo,"\n")
 		}
 	} else {
+		dateinfo="01/01/1900"
 		if (HRVData$Verbose) {
-			dateinfo="01/01/1900"
 			cat("      No date information in header:",dateinfo,"\n")
 		}
 	}
@@ -63,8 +65,6 @@ function(HRVData, RecordName, RecordPath=".", verbose=NULL) {
 	}
 	HRVData$datetime=datetimeaux
 
-	setwd(dir)
-
 	return(HRVData)
 
 }
